@@ -1,5 +1,6 @@
-from cms.models import CMSPlugin
 from django.db import models
+
+from cms.models import CMSPlugin
 from filer.fields.image import FilerImageField
 
 
@@ -9,15 +10,10 @@ class ContentWidthImage(CMSPlugin):
     """
 
     image = FilerImageField(
-        related_name="+",
-        verbose_name="Content Width Image",
-        on_delete=models.SET_NULL,
-        null=True,
+        related_name="+", verbose_name="Content Width Image", on_delete=models.SET_NULL, null=True,
     )
-    caption = models.CharField(
-        max_length=255, help_text="Add a caption to the image", blank=True, default=""
-    )
-    alt_text = models.CharField(max_length=64, help_text="Image name", default="")
+    alt_text = models.CharField(max_length=64, help_text="Image name", blank=True, default="")
+    caption = models.CharField(max_length=255, help_text="Add a caption to the image")
     credit = models.CharField(max_length=255)
 
     def __str__(self):
